/**
 * The MIT License
 *
 * Copyright (c) 2010-2011 Sonatype, Inc. All rights reserved.
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 * THE SOFTWARE.
 */

package org.hudsonci.plugins.blacklist;

import com.google.inject.ImplementedBy;
import org.hudsonci.plugins.blacklist.internal.BlacklistManagerImpl;

/**
 * Manages {@link BlacklistedFeature}s.
 * 
 * @author Jamie Whitehouse
 */
@ImplementedBy( BlacklistManagerImpl.class )
public interface BlacklistManager
{
    /**
     * Disables all blacklisted features.
     */
    void disableAllFeatures();

    /**
     * Enables all blacklisted features.
     */
    void enableAllFeatures();

    /**
     * Disables a specific blacklisted feature.
     * 
     * @param featureName the name for a feature, usually the classes simple name.
     */
    void disableFeature( String featureName );

    /**
     * Enables a specific blacklisted feature.
     * 
     * @param featureName the name for a feature, usually the classes simple name.
     */
    void enableFeature( String featureName );
}
